diff --git a/MediaBrowser.Model/Registration/RegistrationInfo.cs b/MediaBrowser.Model/Registration/RegistrationInfo.cs
index da4c27fbd..4e97989cf 100644
--- a/MediaBrowser.Model/Registration/RegistrationInfo.cs
+++ b/MediaBrowser.Model/Registration/RegistrationInfo.cs
@@ -20,9 +20,9 @@ namespace MediaBrowser.Model.Registration
/// true if this instance is trial; otherwise, false.
public bool IsTrial { get; set; }
///
/// Gets or sets a value indicating whether this instance is valid.
///
- /// true if this instance is valid; otherwise, false.
- public bool IsValid { get; set; }
+ /// true if this instance is registered; otherwise, false.
+ public bool IsRegistered { get; set; }
}
}
@@ -20,9 +20,9 @@ namespace MediaBrowser.Model.Registration
public bool IsTrial { get; set; }
///
- /// Gets or sets a value indicating whether this instance is valid.
+ /// Gets or sets a value indicating whether this instance is registered.
///